@@ -95,7 +95,7 @@ qcs::cam::uin/12345678:role/tencentcloudServiceRole/4611686018427397920、qcs::c
         :type DurationSeconds: int
         :param _Policy: 策略描述
 注意：
-1、policy 需要做 urlencode（如果通过 GET 方法请求云 API，发送请求前，所有参数都需要按照[云 API 规范](https://cloud.tencent.com/document/api/598/33159#1.-.E6.8B.BC.E6.8E.A5.E8.A7.84.E8.8C.83.E8.AF.B7.E6.B1.82.E4.B8.B2)再 urlencode 一次）。
+1、该参数需要做urlencode，服务端会对该字段做urldecode， 并按处理后Policy授予临时访问凭证权限，请按规范传入参数。（如果通过 GET 方法请求云 API，发送请求前，所有参数都需要按照[云 API 规范](https://cloud.tencent.com/document/api/598/33159#1.-.E6.8B.BC.E6.8E.A5.E8.A7.84.E8.8C.83.E8.AF.B7.E6.B1.82.E4.B8.B2)再 urlencode 一次）。
 2、策略语法参照[ CAM 策略语法](https://cloud.tencent.com/document/product/598/10603)。
 3、策略中不能包含 principal 元素。
         :type Policy: str
@@ -208,7 +208,7 @@ class AssumeRoleResponse(AbstractModel):
         :type ExpiredTime: int
         :param _Expiration: 临时访问凭证的过期时间，以 iso8601 格式的 UTC 时间表示
         :type Expiration: str
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._Credentials = None
@@ -352,7 +352,7 @@ class AssumeRoleWithSAMLResponse(AbstractModel):
         :type ExpiredTime: int
         :param _Expiration: 临时访问凭证的过期时间，以 ISO8601 格式的 UTC 时间表示
         :type Expiration: str
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._Credentials = None
@@ -496,7 +496,7 @@ class AssumeRoleWithWebIdentityResponse(AbstractModel):
         :type Expiration: str
         :param _Credentials: 临时访问凭证
         :type Credentials: :class:`tencentcloud.sts.v20180813.models.Credentials`
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._ExpiredTime = None
@@ -631,7 +631,7 @@ class GetCallerIdentityResponse(AbstractModel):
         :type PrincipalId: str
         :param _Type: 身份类型。
         :type Type: str
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._Arn = None
@@ -708,11 +708,10 @@ class GetFederationTokenRequest(AbstractModel):
         r"""
         :param _Name: 您可以自定义调用方英文名称，由字母组成。
         :type Name: str
-        :param _Policy: 授予该临时访问凭证权限的CAM策略
-注意：
+        :param _Policy: 注意：
 1、策略语法参照[ CAM 策略语法](https://cloud.tencent.com/document/product/598/10603)。
 2、策略中不能包含 principal 元素。
-3、该参数需要做urlencode。
+3、该参数需要做urlencode，服务端会对该字段做urldecode， 并按处理后Policy授予临时访问凭证权限，请按规范传入参数。
         :type Policy: str
         :param _DurationSeconds: 指定临时证书的有效期，单位：秒，默认1800秒，主账号最长可设定有效期为7200秒，子账号最长可设定有效期为129600秒。
         :type DurationSeconds: int
@@ -774,7 +773,7 @@ class GetFederationTokenResponse(AbstractModel):
         :param _Expiration: 临时访问凭证有效的时间，以 iso8601 格式的 UTC 时间表示
 注意：此字段可能返回 null，表示取不到有效值。
         :type Expiration: str
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._Credentials = None
@@ -831,7 +830,7 @@ class QueryApiKeyRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _TargetUin: 待查询的账号(不填默认查当前账号)
+        :param _TargetUin: 待查询的账号uin(不填默认查当前账号uin)
         :type TargetUin: int
         """
         self._TargetUin = None
@@ -864,9 +863,9 @@ class QueryApiKeyResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _IdKeys: 密钥ID列表
+        :param _IdKeys: 密钥ID列表。
         :type IdKeys: list of ApiKey
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._IdKeys = None
